==> keyclic_sdk_api-1.41.8%2B1.tar.gz: lib/model/organization_links.dart <==
part of keyclic_sdk_api.api;

class OrganizationLinks {
  OrganizationLinks({
    this.self,
    this.businessActivity,
    this.logo,
  });

  OrganizationLinks.fromJson(Map<String, dynamic> json) {
    if (json == null) {
      return;
    }
    self = OrganizationLinksSelf.fromJson(json['self']);
    businessActivity =
        OrganizationLinksBusinessActivity.fromJson(json['businessActivity']);
    logo = OrganizationLinksLogo.fromJson(json['logo']);
  }

  OrganizationLinksSelf self;

  OrganizationLinksBusinessActivity businessActivity;

  OrganizationLinksLogo logo;

  @override
  bool operator ==(dynamic other) {
    if (identical(this, other)) {
      return true;
    }

    return other is OrganizationLinks && runtimeType == other.runtimeType;
  }

  @override
  int get hashCode => 0;

  Map<String, dynamic> toJson() {
    return {
      'self': self,
      'businessActivity': businessActivity,
      'logo': logo,
    };
  }

  @override
  String toString() {
    return 'OrganizationLinks[self=$self, businessActivity=$businessActivity, logo=$logo, ]';
  }

  static List<OrganizationLinks> listFromJson(List<dynamic> json) {
    return json == null
        ? List<OrganizationLinks>()
        : json.map((value) => OrganizationLinks.fromJson(value)).toList();
  }

  static Map<String, OrganizationLinks> mapFromJson(Map<String, dynamic> json) {
    var map = Map<String, OrganizationLinks>();
    if (json != null && json.isNotEmpty) {
      json.forEach((String key, dynamic value) =>
          map[key] = OrganizationLinks.fromJson(value));
    }
    return map;
  }
}

==> keyclic_sdk_api-2.0.3%2B1.tar.gz: lib/model/organization_links.dart <==
part of keyclic_sdk_api.api;

class OrganizationLinks {
  OrganizationLinks({
    this.application,
    this.businessActivity,
    this.logo,
    this.self,
  });

  OrganizationLinks.fromJson(Map<String, dynamic> json) {
    if (json == null) {
      return;
    }
    application = OrganizationLinksApplication.fromJson(json['application']);
    businessActivity =
        OrganizationLinksBusinessActivity.fromJson(json['businessActivity']);
    logo = OrganizationLinksLogo.fromJson(json['logo']);
    self = OrganizationLinksSelf.fromJson(json['self']);
  }

  OrganizationLinksApplication application;

  OrganizationLinksBusinessActivity businessActivity;

  OrganizationLinksLogo logo;

  OrganizationLinksSelf self;

  @override
  bool operator ==(dynamic other) {
    // Same reference
    if (identical(this, other)) {
      return true;
    }

    return other is OrganizationLinks &&
        runtimeType == other.runtimeType &&
        application == other.application &&
        businessActivity == other.businessActivity &&
        logo == other.logo &&
        self == other.self;
  }

  /// By default hashCode return reference
  @override
  int get hashCode =>
      0 ^
      application.hashCode ^
      businessActivity.hashCode ^
      logo.hashCode ^
      self.hashCode;

  static List<OrganizationLinks> listFromJson(List<dynamic> json) {
    return json == null
        ? <OrganizationLinks>[]
        : json.map((value) => OrganizationLinks.fromJson(value)).toList();
  }

  static Map<String, OrganizationLinks> mapFromJson(Map<String, dynamic> json) {
    var map = Map<String, OrganizationLinks>();
    if (json != null && json.isNotEmpty) {
      json.forEach((String key, dynamic value) =>
          map[key] = OrganizationLinks.fromJson(value));
    }
    return map;
  }

  Map<String, dynamic> toJson() {
    return {
      'application': application,
      'businessActivity': businessActivity,
      'logo': logo,
      'self': self,
    };
  }

  @override
  String toString() {
    return 'OrganizationLinks[application=$application, businessActivity=$businessActivity, logo=$logo, self=$self, ]';
  }
}
